@@ -1,8 +1,8 @@
 ;;; func-menu.el         --- Jump to a function within a buffer.
 ;;;
 ;;; David Hughes <d.hughes@videonetworks.com>
-;;; Last Modified: David Hughes 10th August 1998
-;;; Version: 2.58
+;;; Last Modified: David Hughes 7th September 1998
+;;; Version: 2.61
 ;;; Keywords: tools, c, lisp
 ;;;
 ;;; This program is free software; you can redistribute it and/or modify
@@ -240,7 +240,7 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;  Environment Initialisation  ;;;;;;;;;;;;;;;;;;;;;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(defconst fume-version "2.58")
+(defconst fume-version "2.61")
 
 (defconst fume-developer "David Hughes <d.hughes@videonetworks.com>")
 
@@ -646,17 +646,19 @@ by func-menu, then do something along the lines of the following:
 ;;; Oliver Schittko <schittko@fokus.gmd.de>
 ;;; Tom Murray      <tmurray@hpindck.cup.hp.com>
 ;;; Bob Weiner      <weiner@altrasoft.com> added #define macro support.
+;;; Didier Verna    <verna@inf.enst.fr> avoid matches on macro def last line
 (defvar fume-function-name-regexp-c++
   (cons
    (concat
-    "^\\(#define\\s-+\\|"
+    "\\(\\`\\|[^\\]\n\\)" ; avoid matching on last line of macro definition
+    "\\(#define\\s-+\\|"
     "\\(template\\s-+<[^>]+>\\s-+\\)?"           ; template formals
     "\\([a-zA-Z0-9_*&<,>:]+\\s-+\\)?"            ; type specs; there can be no
     "\\([a-zA-Z0-9_*&<,>\"]+\\s-+\\)?"           ; more than 3 tokens, right?
     "\\([a-zA-Z0-9_*&<,>]+\\s-+\\)?\\)"
     "\\(\\([a-zA-Z0-9_&~:<,>*]\\|\\(\\s +::\\s +\\)\\)+\\)"
     "\\(o?perator\\s *.[^(]*\\)?\\(\\s-\\|\n\\)*(" ; name
-    ) 6)
+    ) 7)
   "Expression to get C++ function names")
 
 ;;; Objective-C
@@ -882,9 +884,10 @@ by func-menu, then do something along the lines of the following:
 
 ;;; Makefiles
 ;;;
+;;; David Hughes <d.hughes@videonetworks.com>
 ;;; Paul Filipski & Anthony Girardin <{filipski,girardin}@blackhawk.com>
 (defvar fume-function-name-regexp-make
-  "^\\(\\(\\$\\s(\\)?\\(\\w\\|\\.\\)+\\(:sh\\)?\\(\\s)\\)?\\)\\s *\\(::?\\|\\+?=\\)"
+  "^\\(\\(\\$\\s(\\)?\\(\\w\\|\\.\\|\\_\\|\\/\\)+\\(:sh\\)?\\(\\s)\\)?\\)\\s *\\(::?\\|\\+?=\\)"
   "Expression to get makefile target names")
 ;; The original version from D.Hughes has this uncommented, but XEmacs 20.4
 ;; has it commented and it is way too slow on non-trivial Makefiles so I'm
@@ -2040,7 +2043,7 @@ If optional arg POPMENU is non-nil, brings up the function-menu."
 
     (save-excursion
       (goto-char pos)
-      (or (fume-bomb-proof (looking-at match-fn))
+      (or (fume-bomb-proof (looking-at (regexp-quote match-fn)))
           (let ((fume-scanning-message nil))
             (fume-rescan-buffer)
             (setq pos (cdr-safe (assoc fn fume-funclist))))))
